@@ -71,8 +71,7 @@ SPOTIFY_CMD = """dbus-send --print-reply --dest={dbus_client}
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     button_next = None
@@ -101,25 +100,20 @@ class Py3status:
         return SPOTIFY_CMD.format(dbus_client=self.dbus_client, cmd=action)
 
     def post_config_hook(self):
-        """
-        """
+        """ """
         # Match string after hyphen, comma, semicolon or slash containing any metadata word
         # examples:
         # - Remastered 2012
         # / Radio Edit
         # ; Remastered
-        self.after_delimiter = self._compile_re(
-            r"([\-,;/])([^\-,;/])*(META_WORDS_HERE).*"
-        )
+        self.after_delimiter = self._compile_re(r"([\-,;/])([^\-,;/])*(META_WORDS_HERE).*")
 
         # Match brackets with their content containing any metadata word
         # examples:
         # (Remastered 2017)
         # [Single]
         # (Bonus Track)
-        self.inside_brackets = self._compile_re(
-            r"([\(\[][^)\]]*?(META_WORDS_HERE)[^)\]]*?[\)\]])"
-        )
+        self.inside_brackets = self._compile_re(r"([\(\[][^)\]]*?(META_WORDS_HERE)[^)\]]*?[\)\]])")
 
     def _compile_re(self, expression):
         """
@@ -203,8 +197,7 @@ class Py3status:
         return response
 
     def on_click(self, event):
-        """
-        """
+        """ """
         button = event["button"]
         if button == self.button_play_pause:
             # we do not use the 'PlayPause' command because of a bug
