@@ -80,9 +80,10 @@ mute
 {'color': '#FF0000', 'full_text': u'\u266a: muted'}
 """
 
-import re
 import math
+import re
 from time import sleep
+
 from py3status.exceptions import CommandError
 
 STRING_ERROR = "invalid command `{}`"
@@ -171,7 +172,9 @@ class Amixer(Audio):
 class Pamixer(Audio):
     def setup(self, parent):
         is_input = "--source" if self.is_input else "--sink"
-        self.cmd = ["pamixer", "--allow-boost", is_input, self.device or "0"]
+        self.cmd = ["pamixer", "--allow-boost"] + (
+            [is_input, self.device] if self.device is not None else []
+        )
 
     def get_volume(self):
         try:
@@ -292,9 +295,7 @@ class Pactl(Audio):
             change = f"{self.max_volume}%"
         else:
             change = f"+{delta}%"
-        self.run_cmd(
-            ["pactl", "--", f"set-{self.device_type}-volume", self.device, change]
-        )
+        self.run_cmd(["pactl", "--", f"set-{self.device_type}-volume", self.device, change])
 
     def volume_down(self, delta):
         self.run_cmd(
